# crypto systems package for BTCS crypto business systems


### Install
```shell
pip install btcs_crypto_systems
```

### Update
```shell
pip install btcs_crypto_systems --upgrade
```

### TokenMaster
```python
from btcs_crypto_systems import token_master

tm = token_master.TokenMaster(env="test")
print(tm.assets[7].symbol)
```

### Utils
```python
from btcs_crypto_systems import utils

csv_writer = utils.get_csv_writer(file_name="example_output_file", headers=["address", "balance"])
csv_writer.writerow(["0x8c8d7c46219d9205f056f28fee5950ad564d7465","1.001"])

#creates a file called 20230217_0853_example_output_file.csv
```

### AMS
```python
from btcs_crypto_systems import ams

```